==> ark-20.07.90.tar.xz: ark-20.07.90/plugins/cliunarchiverplugin/kerfuffle_cliunarchiver.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract RAR archives",
        "Description[ca@valencia]": "Obri i extreu arxius RAR",
        "Description[ca]": "Obre i extreu arxius RAR",
        "Description[cs]": "Otevřít a rozbalit archivy RAR",
        "Description[da]": "Åbn og udpak RAR-arkiver",
        "Description[de]": "Öffnen und Entpacken von RAR-Archiven",
        "Description[el]": "Άνοιγμα και εξαγωγή αρχειοθηκών RAR",
        "Description[en_GB]": "Open and extract RAR archives",
        "Description[es]": "Abrir y extraer archivos RAR",
        "Description[et]": "RAR-arhiivide avamine ja lahtipakkimine",
        "Description[eu]": "Ireki eta erauzi RAR artxiboak",
        "Description[fi]": "Avaa ja pura RAR-arkistoja",
        "Description[fr]": "Ouvre et extrait les archives RAR",
        "Description[gl]": "Abrir e extraer arquivos RAR.",
        "Description[it]": "Apri ed estrai archivi RAR",
        "Description[ko]": "RAR 압축 파일 열고 풀기",
        "Description[nl]": "Open en pak uit RAR-archieven",
        "Description[nn]": "Opna og pakk ut RAR-arkiv",
        "Description[pl]": "Otwiera i wypakowuje archiwa RAR",
        "Description[pt]": "Abrir e extrair os pacotes RAR",
        "Description[pt_BR]": "Abrir e extrair arquivos RAR",
        "Description[ru]": "Открытие и распаковка архивов RAR",
        "Description[sk]": "Otvorenie a extrahovanie archívov RAR",
        "Description[sl]": "Odprite in razširite arhive RAR",
        "Description[sr@ijekavian]": "Отварање и распакивање РАР архива",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje RAR arhiva",
        "Description[sr@latin]": "Otvaranje i raspakivanje RAR arhiva",
        "Description[sr]": "Отварање и распакивање РАР архива",
        "Description[sv]": "Öppna och extrahera RAR-arkiv",
        "Description[tr]": "RAR arşivlerini aç ve çıkar",
        "Description[uk]": "Здатен відкривати і видобувати архіви RAR",
        "Description[x-test]": "xxOpen and extract RAR archivesxx",
        "Description[zh_CN]": "打开和解压 RAR 归档",
        "Description[zh_TW]": "開啟並解壓縮 RAR 壓縮檔",
        "Id": "kerfuffle_cliunarchiver",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "The Unarchiver plugin",
        "Name[ca@valencia]": "Connector de l'Unarchiver",
        "Name[ca]": "Connector de l'Unarchiver",
        "Name[cs]": "Modul pro Unarchiver",
        "Name[da]": "Unarchiver-pluginet",
        "Name[de]": "Unarchiver-Modul",
        "Name[el]": "Πρόσθετο Unarchiver",
        "Name[en_GB]": "The Unarchiver plugin",
        "Name[es]": "El complemento de Unarchiver",
        "Name[et]": "Unarchiveri plugin",
        "Name[eu]": "Unarchiver plugina",
        "Name[fi]": "Unarchiver-tuki",
        "Name[fr]": "Module externe d'extraction d'archive",
        "Name[gl]": "Complemento de desarquivar",
        "Name[he]": "תוסף חילוץ אכיונים",
        "Name[it]": "Estensione The Unarchiver",
        "Name[ko]": "The Unarchiver 플러그인",
        "Name[nl]": "De plug-in voor uit archief halen",
        "Name[nn]": "The Unarchiver-tillegg",
        "Name[pl]": "Wtyczka wypakowywacza",
        "Name[pt]": "O 'plugin' do Unarchiver",
        "Name[pt_BR]": "Plugin Unarchiver",
        "Name[ru]": "Модуль Unarchiver",
        "Name[sk]": "Plugin Unarchiver",
        "Name[sl]": "Vstavek Unarchiver",
        "Name[sr@ijekavian]": "Прикључак Унархивера",
        "Name[sr@ijekavianlatin]": "Priključak Unarchivera",
        "Name[sr@latin]": "Priključak Unarchivera",
        "Name[sr]": "Прикључак Унархивера",
        "Name[sv]": "Unarchiver-insticksprogram",
        "Name[tr]": "Unarchiver eklentisi",
        "Name[uk]": "Додаток Unarchiver",
        "Name[x-test]": "xxThe Unarchiver pluginxx",
        "Name[zh_CN]": "Unarchiver 插件",
        "Name[zh_TW]": "解壓縮外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadOnlyExecutables": [
        "lsar",
        "unar"
    ],
    "X-KDE-Kerfuffle-ReadWrite": false,
    "X-KDE-Priority": 100,
    "application/vnd.rar": {
        "HeaderEncryption": true
    },
    "application/x-rar": {
        "HeaderEncryption": true
    }
}

==> ark-20.08.2.tar.xz: ark-20.08.2/plugins/cliunarchiverplugin/kerfuffle_cliunarchiver.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract RAR archives",
        "Description[az]": "RAR arxivləri açmaq və çıxartmaq",
        "Description[ca@valencia]": "Obri i extreu arxius RAR",
        "Description[ca]": "Obre i extreu arxius RAR",
        "Description[cs]": "Otevřít a rozbalit archivy RAR",
        "Description[da]": "Åbn og udpak RAR-arkiver",
        "Description[de]": "Öffnen und Entpacken von RAR-Archiven",
        "Description[el]": "Άνοιγμα και εξαγωγή αρχειοθηκών RAR",
        "Description[en_GB]": "Open and extract RAR archives",
        "Description[es]": "Abrir y extraer archivos RAR",
        "Description[et]": "RAR-arhiivide avamine ja lahtipakkimine",
        "Description[eu]": "Ireki eta erauzi RAR artxiboak",
        "Description[fi]": "Avaa ja pura RAR-arkistoja",
        "Description[fr]": "Ouvre et extrait les archives RAR",
        "Description[gl]": "Abrir e extraer arquivos RAR.",
        "Description[it]": "Apri ed estrai archivi RAR",
        "Description[ko]": "RAR 압축 파일 열고 풀기",
        "Description[nl]": "Open en pak uit RAR-archieven",
        "Description[nn]": "Opna og pakk ut RAR-arkiv",
        "Description[pl]": "Otwiera i wypakowuje archiwa RAR",
        "Description[pt]": "Abrir e extrair os pacotes RAR",
        "Description[pt_BR]": "Abrir e extrair arquivos RAR",
        "Description[ro]": "Deschide și extrage arhive RAR",
        "Description[ru]": "Открытие и распаковка архивов RAR",
        "Description[sk]": "Otvorenie a extrahovanie archívov RAR",
        "Description[sl]": "Odprite in razširite arhive RAR",
        "Description[sr@ijekavian]": "Отварање и распакивање РАР архива",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje RAR arhiva",
        "Description[sr@latin]": "Otvaranje i raspakivanje RAR arhiva",
        "Description[sr]": "Отварање и распакивање РАР архива",
        "Description[sv]": "Öppna och extrahera RAR-arkiv",
        "Description[tr]": "RAR arşivlerini aç ve çıkar",
        "Description[uk]": "Здатен відкривати і видобувати архіви RAR",
        "Description[x-test]": "xxOpen and extract RAR archivesxx",
        "Description[zh_CN]": "打开和解压 RAR 归档",
        "Description[zh_TW]": "開啟並解壓縮 RAR 壓縮檔",
        "Id": "kerfuffle_cliunarchiver",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "The Unarchiver plugin",
        "Name[az]": "Unarchive qoşması",
        "Name[ca@valencia]": "Connector de l'Unarchiver",
        "Name[ca]": "Connector de l'Unarchiver",
        "Name[cs]": "Modul pro Unarchiver",
        "Name[da]": "Unarchiver-pluginet",
        "Name[de]": "Unarchiver-Modul",
        "Name[el]": "Πρόσθετο Unarchiver",
        "Name[en_GB]": "The Unarchiver plugin",
        "Name[es]": "El complemento de Unarchiver",
        "Name[et]": "Unarchiveri plugin",
        "Name[eu]": "Unarchiver plugina",
        "Name[fi]": "Unarchiver-tuki",
        "Name[fr]": "Module externe d'extraction d'archive",
        "Name[gl]": "Complemento de desarquivar",
        "Name[he]": "תוסף חילוץ אכיונים",
        "Name[it]": "Estensione The Unarchiver",
        "Name[ko]": "The Unarchiver 플러그인",
        "Name[nl]": "De plug-in voor uit archief halen",
        "Name[nn]": "The Unarchiver-tillegg",
        "Name[pl]": "Wtyczka wypakowywacza",
        "Name[pt]": "O 'plugin' do Unarchiver",
        "Name[pt_BR]": "Plugin Unarchiver",
        "Name[ro]": "Extensie de dezarhivare",
        "Name[ru]": "Модуль Unarchiver",
        "Name[sk]": "Plugin Unarchiver",
        "Name[sl]": "Vstavek Unarchiver",
        "Name[sr@ijekavian]": "Прикључак Унархивера",
        "Name[sr@ijekavianlatin]": "Priključak Unarchivera",
        "Name[sr@latin]": "Priključak Unarchivera",
        "Name[sr]": "Прикључак Унархивера",
        "Name[sv]": "Unarchiver-insticksprogram",
        "Name[tr]": "Unarchiver eklentisi",
        "Name[uk]": "Додаток Unarchiver",
        "Name[x-test]": "xxThe Unarchiver pluginxx",
        "Name[zh_CN]": "Unarchiver 插件",
        "Name[zh_TW]": "解壓縮外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadOnlyExecutables": [
        "lsar",
        "unar"
    ],
    "X-KDE-Kerfuffle-ReadWrite": false,
    "X-KDE-Priority": 100,
    "application/vnd.rar": {
        "HeaderEncryption": true
    },
    "application/x-rar": {
        "HeaderEncryption": true
    }
}
